/**
 * @license
 * Copyright 2021 Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
/**
 * @fileoverview Overrides metrics to exclude the flyout from the viewport.
 */
import * as Blockly from 'blockly/core';
/** Computes metrics for a toolbox with an always open flyout. */
export declare class ContinuousMetrics extends Blockly.MetricsManager {
    /**
     * Computes the viewport size to not include the toolbox and the flyout.
     * The default viewport includes the flyout.
     *
     * @param getWorkspaceCoordinates True to get the view metrics in workspace
     *     coordinates, false to get them in pixel coordinates.
     * @returns The width, height, top and left of the viewport in either
     *     workspace coordinates or pixel coordinates.
     */
    getViewMetrics(getWorkspaceCoordinates?: boolean): Blockly.MetricsManager.ContainerRegion;
    /**
     * Gets the absolute left and absolute top in pixel coordinates.
     * This is where the visible workspace starts in relation to the SVG
     * container, adjusted to not include the area behind the flyout.
     *
     * @returns The absolute metrics for the workspace.
     */
    getAbsoluteMetrics(): Blockly.MetricsManager.AbsoluteMetrics;
}
//# sourceMappingURL=ContinuousMetrics.d.ts.map